import arcade

class Tile(arcade.SpriteSolidColor):
    def __init__(self, x, y, start_x, start_y, size=100, spacing=10, scale=0.5, color=arcade.color.AMBER):

        super().__init__(size, size, color=color)

        self.size = size
        self.spacing = spacing

        self.position = (
            start_x + x*(size + spacing),
            start_y - y*(size + spacing)
        )


class Pad():
    def __init__(self, x, y, row=6, column=6, size=100, spacing=10):
        self.row = row
        self.column = column
        self.pos = (x, y)
        self.tiles = arcade.SpriteList()

        for r in range(row):
            for c in range(column):
                self.tiles.append(
                        Tile(
                            x=c,
                            y=r,
                            start_x=x,
                            start_y=y,
                            size=size,
                            spacing=spacing
                        )
                    )

    def get_instructions(self, token_list):
        instructions = []
        if len(token_list) > 0:
            for tile in self.tiles:
                token, distance = arcade.get_closest_sprite(tile, token_list)
                if arcade.check_for_collision(token, tile):
                    token_type = str(token.token_type)

                    if token_type == "forward":
                        instructions.append("forward")

                    if token_type == "left":
                        instructions.append("left")

                    if token_type == "right":
                        instructions.append("right")
            
        return instructions
